@@ -1,14 +1,11 @@
 #include <lib/vcsn/algos/registry.hh>
+#include <lib/vcsn/dyn/signature-printer.hh>
 #include <vcsn/core/rat/identities.hh>
 #include <vcsn/dyn/algos.hh>
-#include <vcsn/dyn/label.hh>
 #include <vcsn/dyn/automaton.hh>
 #include <vcsn/dyn/context.hh>
-#include <vcsn/dyn/polynomial.hh>
 #include <vcsn/dyn/registries.hh>
-#include <vcsn/dyn/signature-printer.hh>
-#include <vcsn/dyn/translate.hh>
-#include <vcsn/misc/builtins.hh>
+#include <vcsn/dyn/value.hh>
 #include <vcsn/misc/getargs.hh>
 
 namespace vcsn
@@ -50,15 +47,15 @@ namespace vcsn
     }
 
 
-    /*----------------.
-    | infiltration.   |
-    `----------------*/
+    /*--------------.
+    | infiltrate.   |
+    `--------------*/
 
     automaton
-    infiltration(const automaton& lhs, const automaton& rhs)
+    infiltrate(const automaton& lhs, const automaton& rhs)
     {
       auto auts = std::vector<automaton>{lhs, rhs};
-      return infiltration(auts);
+      return infiltrate(auts);
     }
 
 
@@ -98,8 +95,8 @@ namespace vcsn
     context
     make_context(const std::string& n)
     {
-      symbol sname{ast::normalize_context(n, false)};
-      std::string full_name = ast::normalize_context(n, true);
+      auto sname = symbol{ast::normalize_context(n, false)};
+      auto full_name = ast::normalize_context(n, true);
       if (!detail::make_context_registry().get0({sname}))
         compile(sname);
       return detail::make_context_registry().call({sname}, full_name);
@@ -126,6 +123,22 @@ namespace vcsn
       return detail::project_context_registry().call(ctx, t);
     }
 
+    REGISTRY_DEFINE(project_expansion);
+    expansion
+    project(const expansion& e, unsigned tape)
+    {
+      auto t = to_integral_constant(tape);
+      return detail::project_expansion_registry().call(e, t);
+    }
+
+    REGISTRY_DEFINE(project_expression);
+    expression
+    project(const expression& e, unsigned tape)
+    {
+      auto t = to_integral_constant(tape);
+      return detail::project_expression_registry().call(e, t);
+    }
+
     REGISTRY_DEFINE(project_polynomial);
     polynomial
     project(const polynomial& p, unsigned tape)
@@ -174,6 +187,10 @@ namespace vcsn
             {"expansion",    [](const expression& r) {
                 return strip(trim(strip(derived_term(r))));
               }},
+            {"inductive", "inductive,standard"},
+            {"inductive,standard",    [](const expression& r) {
+                return inductive(r, "standard");
+              }},
             {"standard",     [](const expression& r) {
                 return standard(r);
               }},
@@ -183,7 +200,8 @@ namespace vcsn
             {"zpc",          [](const expression& r) {
                 return strip(trim(zpc(r)));
               }},
-            {"zpc_compact",  [](const expression& r) {
+            {"zpc_compact",  "zpc,compact"},
+            {"zpc,compact",  [](const expression& r) {
                 return strip(trim(zpc(r, "compact")));
               }},
           }
@@ -196,11 +214,25 @@ namespace vcsn
     | tuple.   |
     `---------*/
 
+    automaton
+    tuple(const automaton& lhs, const automaton& rhs)
+    {
+      auto auts = std::vector<automaton>{lhs, rhs};
+      return tuple(auts);
+    }
+
+    context
+    tuple(const context& lhs, const context& rhs)
+    {
+      auto cs = std::vector<context>{lhs, rhs};
+      return tuple(cs);
+    }
+
     expression
     tuple(const expression& lhs, const expression& rhs)
     {
-      auto auts = std::vector<expression>{lhs, rhs};
-      return tuple(auts);
+      auto es = std::vector<expression>{lhs, rhs};
+      return tuple(es);
     }
 
     std::string type(const automaton& a)
