@@ -2,12 +2,8 @@
 #include <vcsn/dyn/algos.hh>
 #include <vcsn/dyn/automaton.hh>
 #include <vcsn/dyn/context.hh>
-#include <vcsn/dyn/expansion.hh>
-#include <vcsn/dyn/expression.hh>
-#include <vcsn/dyn/label.hh>
-#include <vcsn/dyn/polynomial.hh>
 #include <vcsn/dyn/registries.hh>
-#include <vcsn/dyn/weight.hh>
+#include <vcsn/dyn/value.hh>
 #include <vcsn/misc/escape.hh>
 #include <vcsn/misc/raise.hh>
 #include <vcsn/misc/xalloc.hh>
@@ -24,7 +20,8 @@ namespace vcsn
     REGISTRY_DEFINE(print_expansion);
 
     std::ostream&
-    print(const dyn::expansion& w, std::ostream& out, const std::string& format)
+    print(const dyn::expansion& w, std::ostream& out,
+          const std::string& format)
     {
       if (format == "null")
         {}
@@ -43,6 +40,37 @@ namespace vcsn
       return out;
     }
 
+    /*-----------------------------.
+    | print(expression, stream).   |
+    `-----------------------------*/
+
+    REGISTRY_DEFINE(print_expression);
+
+    std::ostream&
+    print(const expression& exp, std::ostream& out, const std::string& format)
+    {
+      if (format == "info")
+        info(exp, out);
+      else if (format == "null")
+        {}
+      else if (format == "dot"
+               || format == "dot,logical" || format == "dot,physical"
+               || format == "latex" || format == "utf8")
+        detail::print_expression_registry().call(exp, out, format);
+      else if (format == "text" || format == "default" || format == "")
+        {
+          // FIXME: problem with rvalue if we pass
+          // 'std::string("text")'.
+          // FIXME: We _need_ the const, see name.hh.
+          const std::string format = "text";
+          detail::print_expression_registry().call(exp, out, format);
+        }
+      else
+        raise("invalid output format for expression: ", str_escape(format));
+      return out;
+    }
+
+
     /*-----------------------.
     | print(label, stream).  |
     `-----------------------*/
@@ -99,35 +127,6 @@ namespace vcsn
     }
 
 
-    /*-----------------------------.
-    | print(expression, stream).   |
-    `-----------------------------*/
-
-    REGISTRY_DEFINE(print_expression);
-
-    std::ostream&
-    print(const expression& exp, std::ostream& out, const std::string& format)
-    {
-      if (format == "info")
-        info(exp, out);
-      else if (format == "null")
-        {}
-      else if (format == "latex" || format == "utf8")
-        detail::print_expression_registry().call(exp, out, format);
-      else if (format == "text" || format == "default" || format == "")
-        {
-          // FIXME: problem with rvalue if we pass
-          // 'std::string("text")'.
-          // FIXME: We _need_ the const, see name.hh.
-          const std::string format = "text";
-          detail::print_expression_registry().call(exp, out, format);
-        }
-      else
-        raise("invalid output format for expression: ", str_escape(format));
-      return out;
-    }
-
-
     /*------------------------.
     | print(weight, stream).  |
     `------------------------*/
@@ -159,69 +158,62 @@ namespace vcsn
     | ostream format.  |
     `-----------------*/
 
-    xalloc<std::string*> format_flag;
+    xalloc<const std::string*> format_flag;
 
     void
     set_format(std::ostream& o, const std::string& format)
     {
-      if (!format_flag(o))
-        format_flag(o) = new std::string{"default"};
-      *format_flag(o) = format;
+      static auto formats = std::set<std::string>{};
+      format_flag(o) = &*formats.insert(format).first;
     }
 
     std::string
     get_format(std::ostream& o)
     {
-      if (!format_flag(o))
-        format_flag(o) = new std::string{"default"};
-      return *format_flag(o);
+      return format_flag(o) ? *format_flag(o) : std::string{"default"};
     }
 
+
+    std::ostream&
+    operator<<(std::ostream& o, const automaton& a)
+    {
+      return print(a, o, get_format(o));
+    }
+
+    std::ostream&
+    operator<<(std::ostream& o, const context& c)
+    {
+      return print(c, o, get_format(o));
+    }
+
+    std::ostream&
+    operator<<(std::ostream& o, const expansion& e)
+    {
+      return print(e, o, get_format(o));
+    }
+
+    std::ostream&
+    operator<<(std::ostream& o, const expression& r)
+    {
+      return print(r, o, get_format(o));
+    }
+
+    std::ostream&
+    operator<<(std::ostream& o, const label& l)
+    {
+      return print(l, o, get_format(o));
+    }
+
+    std::ostream&
+    operator<<(std::ostream& o, const polynomial& p)
+    {
+      return print(p, o, get_format(o));
+    }
+
+    std::ostream&
+    operator<<(std::ostream& o, const weight& w)
+    {
+      return print(w, o, get_format(o));
+    }
   }
 }
-
-namespace std
-{
-  std::ostream&
-  operator<<(std::ostream& o, const vcsn::dyn::automaton& a)
-  {
-    return vcsn::dyn::print(a, o, vcsn::dyn::get_format(o));
-  }
-
-  std::ostream&
-  operator<<(std::ostream& o, const vcsn::dyn::context& c)
-  {
-    return vcsn::dyn::print(c, o, vcsn::dyn::get_format(o));
-  }
-
-  std::ostream&
-  operator<<(std::ostream& o, const vcsn::dyn::expansion& e)
-  {
-    return vcsn::dyn::print(e, o, vcsn::dyn::get_format(o));
-  }
-
-  std::ostream&
-  operator<<(std::ostream& o, const vcsn::dyn::expression& r)
-  {
-    return vcsn::dyn::print(r, o, vcsn::dyn::get_format(o));
-  }
-
-  std::ostream&
-  operator<<(std::ostream& o, const vcsn::dyn::label& l)
-  {
-    return vcsn::dyn::print(l, o, vcsn::dyn::get_format(o));
-  }
-
-  std::ostream&
-  operator<<(std::ostream& o, const vcsn::dyn::polynomial& p)
-  {
-    return vcsn::dyn::print(p, o, vcsn::dyn::get_format(o));
-  }
-
-  std::ostream&
-  operator<<(std::ostream& o, const vcsn::dyn::weight& w)
-  {
-    return vcsn::dyn::print(w, o, vcsn::dyn::get_format(o));
-  }
-
-}
