@@ -1,13 +1,10 @@
-#include <vcsn/dyn/context-printer.hh>
-
-#include <map>
+#include <lib/vcsn/dyn/context-printer.hh>
 
 #include <boost/algorithm/string/predicate.hpp>
 
-#include <vcsn/dyn/type-ast.hh>
+#include <lib/vcsn/dyn/type-ast.hh>
 #include <vcsn/misc/getargs.hh>
 #include <vcsn/misc/indent.hh>
-#include <vcsn/misc/raise.hh>
 
 
 namespace vcsn
@@ -33,7 +30,6 @@ namespace vcsn
 
     std::ostream& context_printer::print(std::ostream& o)
     {
-      //o << "// " << is.str() << "\n";
       o <<
         "#define BUILD_LIBVCSN 1\n"
         "#define VCSN_INSTANTIATION 1\n"
@@ -44,7 +40,7 @@ namespace vcsn
       o << '\n';
       for (const auto& h: headers_late_)
         o << "#include <" << h << ">\n";
-      o << "\n"
+      o << '\n'
         << os_.str();
       return o;
     }
@@ -168,18 +164,18 @@ namespace vcsn
 
     DEFINE(expressionset)
     {
+      header("vcsn/core/rat/expressionset.hh");
       os_ << "vcsn::expressionset<" << incendl;
       t.get_context()->accept(*this);
       os_ << decendl << '>';
-      header("vcsn/core/rat/expressionset.hh");
     }
 
     DEFINE(expansionset)
     {
+      header("vcsn/core/rat/expansionset.hh");
       os_ << "vcsn::rat::expansionset<" << incendl;
       t.get_expressionset()->accept(*this);
       os_ << decendl << '>';
-      header("vcsn/core/rat/expansionset.hh");
     }
 
     DEFINE(weightset)
@@ -207,10 +203,10 @@ namespace vcsn
 
     DEFINE(polynomialset)
     {
+      header("vcsn/weightset/polynomialset.hh");
       os_ << "vcsn::polynomialset<" << incendl;
       t.get_content()->accept(*this);
       os_ << decendl << '>';
-      header("vcsn/weightset/polynomialset.hh");
     }
 #undef DEFINE
   }
