@@ -1,21 +1,18 @@
 import re
+import sys
 
+# pylint: disable=import-error
+import ipywidgets as widgets
 from IPython.core.magic import (Magics, magics_class, line_magic)
 from IPython.core.magic_arguments import (
     argument, magic_arguments, parse_argstring)
-try:
-    import ipywidgets as widgets
-except ImportError:
-    from IPython.html import widgets
-from IPython.display import display
-from pylab import *
+
 import matplotlib.pyplot as plt
 import pandas as pd
 
-import vcsn
 
 # some parameters
-pd.set_option('display.mpl_style', 'default')
+plt.style.use('default')
 pd.set_option('display.max_rows', 500)
 pd.set_option('display.max_columns', 500)
 
@@ -32,6 +29,10 @@ class Benchmarks(Magics):
               graph. Default: line''')
     @line_magic
     def plot(self, line):
+        # if we are not running in a notebook
+        if 'connection_file' not in ip.config['IPKernelApp']:
+            print('This functionnality is only available in notebooks.', file=sys.stderr)
+            return
         def _display(algo, several):
             group = df[algo]
             ax = group.plot(kind=args.mode)
@@ -39,11 +40,21 @@ class Benchmarks(Magics):
                 ax.legend(loc='center left', bbox_to_anchor=(1, 0.5))
             else:
                 plt.title(algo)
-            ax = plt.figure()
         args = parse_argstring(self.plot, line)
-        df = pd.read_csv(args.file)
-        df.index = df[' ']
-        df = df.drop(' ', 1)
+        df = pd.read_csv(args.file,
+                         # Consider 'N/A' etc. as NaN
+                         na_values=['FAIL', 'N/A'],
+                         skipinitialspace=True)
+        # Compound titles
+        def format(x):
+            if x > 1:
+                return ', ' + str(x) + 'x'
+            return ''
+        df.index = df['Command'] + ' # ' + df['Setup'] + df['Repetitions'].map(format)
+        # Drop now useless columns
+        df = df.drop(['Command','Setup','Repetitions'], 1)
+        # Swap axes to get back to old score-compare format
+        df = df.T
         if args.regex:
             algos = []
             for ag in list(df.columns.values):
@@ -52,7 +63,8 @@ class Benchmarks(Magics):
             _display(algos, True)
         else:
             algos = list(df.columns.values)
-            widget.interact(lambda algo: _display(algo, False), algo=algos)
+            widgets.interact(lambda algo: _display(algo, False), algo=algos)
 
 ip = get_ipython()
 ip.register_magics(Benchmarks)
+ip.magic("matplotlib inline")
