@@ -22,10 +22,18 @@ def _info_to_dict(info):
     '''Convert a "key: value" list of lines into a dictionary.
     Convert Booleans into bool, and likewise for integers.
     '''
-    res = dict()
-    for l in info.splitlines():
-        (k, v) = l.split(':', 1)
+    res = {}
+    # Since Python 3.7, dictionaries are guaranteed to preserve the
+    # order.  So let's use a nice one.
+    #
+    # We used to rely on IPython displaying dictionaries in order in
+    # our test-suite (doc/notebooks), but with Python 3.7, IPython no
+    # longer sorts the dictionaries.  Sorting here although makes it
+    # easier for our tests.
+    for l in sorted(info.splitlines()):
+        k, v = l.split(':', 1)
         v = v.strip()
+
         # Beware that we may display "N/A" for Boolean (e.g., "is
         # ambiguous" for non LAL), and for integers (e.g., "number of
         # deterministic states" for non LAL).
