@@ -1,8 +1,12 @@
-require.config({paths: {d3: "//d3js.org/d3.v3.min"}});
-require(['widgets/js/widget','d3','jquery','underscore'],
-function(WidgetManager, d3, $,  _){
+require.config({paths: {d3: "http://d3js.org/d3.v3.min"}});
 
-    var AutomatonView = IPython.DOMWidgetView.extend({
+// In case an old version is already loaded.
+require.undef('AutomatonD3Widget');
+
+define('AutomatonD3Widget',
+       ['jupyter-js-widgets', 'd3'],
+       function(widgets, d3) {
+    var AutomatonView = widgets.DOMWidgetView.extend({
 
         // RENDER THE VIEW
         render: function(){
@@ -45,7 +49,7 @@ function(WidgetManager, d3, $,  _){
             this.states = this.model.get('states');
             var trans = this.model.get('transitions');
             this.transitions = this.completeTransitions(trans);
-            this.lastStateId = this.states[this.states.length - 1].id;
+            this.lastStateId = lastStateValidId(this.states);
 
             // Define here to avoid recreation in every update
             this.path = this.svg.append('svg:g').selectAll('g');
@@ -75,7 +79,7 @@ function(WidgetManager, d3, $,  _){
             var that = this;
 
             // Catch source and target with their ID
-            for(var c = 0; c <= this.transitions.length -1; c++)
+            for(var c = 0; c < this.transitions.length; c++)
                 {
                     this.transitions[c].source = this.idToState(this.transitions[c].source);
                     this.transitions[c].target = this.idToState(this.transitions[c].target);
@@ -292,7 +296,10 @@ function(WidgetManager, d3, $,  _){
                 // insert new state at point
                 var point = d3.mouse(doc);
                 var lastState = this.lastStateValidId(this.states);
-                var state = {id: lastState + 1};
+                console.log('"' + lastState + '"');
+                var newid = parseInt(lastState) + 1;
+                console.log('"' + lastState + '" -> "' + newid + '"');
+                var state = {id: newid.toString()};
                 state.x = point[0];
                 state.y = point[1];
                 var new_states = this.model.get('states').slice();
@@ -515,7 +522,7 @@ function(WidgetManager, d3, $,  _){
 
         // METHODS
         idToState: function(id){
-            for(var j=0; j <= this.states.length -1; j++)
+            for(var j=0; j < this.states.length; j++)
                 {
                     if(this.states[j].id == id)
                         {
@@ -524,7 +531,7 @@ function(WidgetManager, d3, $,  _){
                 }
         },
         existingTrans: function(transition, transitions){
-            for(var i=0; i<= transitions.length -1; i++){
+            for(var i=0; i< transitions.length; i++){
                 if((transitions[i].source == transition.target) &&
                   (transitions[i].target == transition.source)){
                     return true;
@@ -533,18 +540,21 @@ function(WidgetManager, d3, $,  _){
             return false;
         },
         lastStateValidId: function(states){
-            for(var t = states.length -1; t>=0; t--)
-                    {
-                        if((parseFloat((states[t].id)) == parseInt((states[t].id)))
-                           && !isNaN((states[t].id)))
-                            {
-                                return states[t].id;
-                            }
-                    }
-
+            var max = 0;
+            for(var t = 0; t < states.length; t++)
+                {
+                    var statenum = parseInt(states[t].id);
+                    if((parseFloat((states[t].id)) == statenum)
+                       && !isNaN((states[t].id)))
+                        {
+                            if(max < statenum)
+                                max = statenum;
+                        }
+                }
+            return max.toString();
         },
         findFinalState: function(state, states){
-            for(var i = 0; i <= states.length -1; i++)
+            for(var i = 0; i < states.length; i++)
                 {
                     if(states[i].id.toString() == (state.id.toString() + '.2'))
                         {
@@ -553,7 +563,7 @@ function(WidgetManager, d3, $,  _){
                 }
         },
         findInitialState: function(state, states){
-            for(var i = 0; i <= states.length -1; i++)
+            for(var i = 0; i < states.length; i++)
                 {
                     if(states[i].id.toString() == (state.id.toString() + '.1'))
                         {
@@ -562,7 +572,7 @@ function(WidgetManager, d3, $,  _){
                 }
         },
         isInitial: function(state, transitions){
-                for(var i=0; i<= transitions.length -1; i++)
+                for(var i=0; i< transitions.length; i++)
                     {
                         if(transitions[i].source.id == state.id ||
                            transitions[i].target.id == state.id)
@@ -578,7 +588,7 @@ function(WidgetManager, d3, $,  _){
                 return false;
         },
         isFinal: function(state, transitions){
-                for(var i=0; i<= transitions.length -1; i++)
+                for(var i=0; i< transitions.length; i++)
                     {
                         if(transitions[i].source.id == state.id ||
                            transitions[i].target.id == state.id)
@@ -614,7 +624,7 @@ function(WidgetManager, d3, $,  _){
 
         },
         isLoop: function(state, transitions){
-                for(var i =0; i <= transitions.length -1; i++)
+                for(var i =0; i < transitions.length; i++)
                     {
                         if(transitions[i].target.id == transitions[i].source.id)
                             {
@@ -627,7 +637,7 @@ function(WidgetManager, d3, $,  _){
                 return false;
         },
         idToNode: function(id){
-            for(var j=0; j <= this.states.length -1; j++)
+            for(var j=0; j < this.states.length; j++)
                 {
                     if(this.states[j].id == id)
                         {
@@ -636,7 +646,7 @@ function(WidgetManager, d3, $,  _){
                 }
         },
         completeTransitions: function(transitions){
-                for(var i =0; i <= transitions.length -1; i++)
+                for(var i =0; i < transitions.length; i++)
                     {
                         if(transitions[i].length != 3)
                             {
@@ -925,5 +935,8 @@ function(WidgetManager, d3, $,  _){
             this.force.start();
         }
     });
-    WidgetManager.register_widget_view("AutomatonView", AutomatonView);
+
+    return {
+        AutomatonView: AutomatonView
+    }
 });
