@@ -6,7 +6,7 @@ from test import *
 ctx = vcsn.context("lal_char(abc), seriesset<lal_char(xyz), q>")
 
 def check_derived_term(r, exp, algo):
-    print("{}: Checking: {}.derived_term({})".format(here(), r, algo))
+    print('{}: checking: {:u}.derived_term("{}")'.format(here(), r, algo))
     if algo == 'lazy,expansion':
         # When checking the lazy construction, make sure we have a
         # derived_term_automaton, then snapshot it at the beginning
@@ -17,18 +17,23 @@ def check_derived_term(r, exp, algo):
         # against the strict computation.
         lazy = r.derived_term(algo)
         CHECK(lazy.type().startswith('derived_term_automaton'))
-        first = str(lazy)
-        # Force the evaluation of the empty word to start computing
-        # the automaton.
-        lazy('')
-        second = str(lazy)
-        CHECK_NE(second, first)
-        lazy.accessible()
-        CHECK_NE(lazy, second)
-        eff = lazy.strip()
+        # FIXME: we don't support evaluate on non-free.  #101.
+        if r.info('tuple') == 0:
+            first = str(lazy)
+            # Force the evaluation of the empty word to start computing
+            # the automaton.
+            lazy('')
+            second = str(lazy)
+            CHECK_NE(second, first)
+            lazy.accessible()
+            CHECK_NE(lazy, second)
+            eff = lazy.strip()
+        else:
+            lazy.accessible()
+            eff = lazy.strip()
     else:
         eff = r.derived_term(algo)
-    CHECK_EQ(open(medir + '/' + exp + '.gv').read().strip(),
+    CHECK_EQ(metext(exp, 'gv'),
              eff)
 
 def check_dt(r, exp):
@@ -40,16 +45,16 @@ def check_bdt(r, exp):
     'Check broken derived-term automaton.'
     if not isinstance(r, vcsn.expression):
         r = ctx.expression(r)
-    for algo in ['breaking_derivation', 'breaking_expansion']:
+    for algo in ['derivation,breaking', 'expansion,breaking']:
         check_derived_term(r, exp, algo)
 
 def check(re, s, exp, breaking=False):
-    "Check that d/ds(re) = exp."
+    "Check that ∂/∂s(re) = exp."
     if not isinstance(re, vcsn.expression):
         re = ctx.expression(re)
     eff = re.derivation(s, breaking)
-    print("d/d{}({}) = {}".format(s, re, eff))
-    CHECK_EQ(exp, str(eff))
+    print("∂/∂{}({:u}) = {:u}".format(s, re, eff))
+    CHECK_EQ(exp, eff)
     # Check that the breaking derivation is exactly the breaking of
     # the regular derivation.
     if breaking:
@@ -77,81 +82,96 @@ CHECK_EQ('b+a',
 ## ---------------------------- ##
 
 # Zero, one.
-check(   '\z', 'a', '\z')
-check(   '\e', 'a', '\z')
-check('<x>\e', 'a', '\z')
+check(   r'\z', 'a', r'\z')
+check(   r'\e', 'a', r'\z')
+check(r'<x>\e', 'a', r'\z')
 
 # Letters.
-check(   'a', 'a', '\e')
-check(   'a', 'b', '\z')
-check('<x>a', 'a', '<x>\e')
-check('<x>a', 'b', '\z')
+check(   'a', 'a', r'\e')
+check(   'a', 'b', r'\z')
+check('<x>a', 'a', r'<x>\e')
+check('<x>a', 'b', r'\z')
 
 # Sum.
-check('<x>a+<y>b', 'a', '<x>\e')
-check('<x>a+<y>b', 'b', '<y>\e')
-check('<x>a+<y>a', 'a', '<x+y>\e')
+check('<x>a+<y>b', 'a', r'<x>\e')
+check('<x>a+<y>b', 'b', r'<y>\e')
+check('<x>a+<y>a', 'a', r'<x+y>\e')
 
 # Prod.
 check('ab', 'a', 'b')
-check('ab', 'b', '\z')
+check('ab', 'b', r'\z')
 check('(<x>a).(<y>a).(<z>a)', 'a', '<x><y>a<z>a')
 
 # Conjunction.
-check('<x>a&<y>a&<z>a', 'a', '<xyz>\e')
-check('<x>a&<y>a&<z>a', 'b', '\z')
+check('<x>a&<y>a&<z>a', 'a', r'<xyz>\e')
+check('<x>a&<y>a&<z>a', 'b', r'\z')
 
-check('(<x>a+<y>b)*&(<z>b+<x>c)*', 'a', '\z')
+check('(<x>a+<y>b)*&(<z>b+<x>c)*', 'a', r'\z')
 check('(<x>a+<y>b)*&(<z>b+<x>c)*', 'b', '<yz>(<x>a+<y>b)*&(<z>b+<x>c)*')
-check('(<x>a+<y>b)*&(<z>b+<x>c)*', 'c', '\z')
+check('(<x>a+<y>b)*&(<z>b+<x>c)*', 'c', r'\z')
 
 # Shuffle.
-check('<x>a:<y>a:<z>a', 'a', '<x>\e:<y>a:<z>a + <y><x>a:\e:<z>a + <z><x>a:<y>a:\e')
-check('<x>a:<y>b:<z>c', 'a', '<x>\e:<y>b:<z>c')
-check('<x>a:<y>b:<z>c', 'b', '<y><x>a:\e:<z>c')
-check('<x>a:<y>b:<z>c', 'c', '<z><x>a:<y>b:\e')
+check('<x>a:<y>a:<z>a', 'a', r'<x>\e:<y>a:<z>a + <y><x>a:\e:<z>a + <z><x>a:<y>a:\e')
+check('<x>a:<y>b:<z>c', 'a', r'<x>\e:<y>b:<z>c')
+check('<x>a:<y>b:<z>c', 'b', r'<y><x>a:\e:<z>c')
+check('<x>a:<y>b:<z>c', 'c', r'<z><x>a:<y>b:\e')
 
 check('(<x>a<y>b)*:(<x>a<x>c)*',
       'a', '<x>(<x>a<y>b)*:<x>c(<x>a<x>c)* + <x><y>b(<x>a<y>b)*:(<x>a<x>c)*')
-check('(<x>a<y>b)*:(<x>a<x>c)*', 'b', '\z')
-check('(<x>a<y>b)*:(<x>a<x>c)*', 'c', '\z')
+check('(<x>a<y>b)*:(<x>a<x>c)*', 'b', r'\z')
+check('(<x>a<y>b)*:(<x>a<x>c)*', 'c', r'\z')
 
 # Star.
 check('a*', 'a', 'a*')
-check('a*', 'b', '\z')
+check('a*', 'b', r'\z')
 check('(<x>a)*', 'a', '<x>(<x>a)*')
-check('(<x>a)*', 'b', '\z')
+check('(<x>a)*', 'b', r'\z')
 check('<x>a*',   'a', '<x>a*')
 check('<x>(<y>a)*', 'a', '<xy>(<y>a)*')
 check('(<x>a)*<y>', 'a', '<x>(<x>a)*<y>')
 check('(<x>a)*<y>', 'aa', '<xx>(<x>a)*<y>')
 
+XFAIL(lambda: vcsn.Q.expression('a**').derivation('a'),
+      r'''Q: value is not starrable: 1
+  while computing derivative of: a**
+                with respect to: a''')
+
+XFAIL(lambda: vcsn.Q.expression('a**').derived_term(),
+      r'''Q: value is not starrable: 1
+  while computing expansion of: a**
+  while computing derived-term of: a**''')
+
+XFAIL(lambda: vcsn.Q.expression('a**').derived_term('derivation'),
+      r'''Q: value is not starrable: 1
+  while computing constant-term of: a**
+  while computing derived-term of: a**''')
+
 
 # Complement.
-check('\z{c}', 'a', '\z{c}')
-check('\e{c}', 'a', '\z{c}')
+check(r'\z{c}', 'a', r'\z{c}')
+check(r'\e{c}', 'a', r'\z{c}')
 
-check('a{c}', 'a', '\e{c}')
-check('a{c}', 'b', '\z{c}')
+check('a{c}', 'a', r'\e{c}')
+check('a{c}', 'b', r'\z{c}')
 
-check('(a+b){c}', 'a', '\e{c}')
-check('(a+b){c}', 'c', '\z{c}')
+check('(a+b){c}', 'a', r'\e{c}')
+check('(a+b){c}', 'c', r'\z{c}')
 
 check('(a.b){c}', 'a', 'b{c}')
-check('(a.b){c}', 'b', '\z{c}')
+check('(a.b){c}', 'b', r'\z{c}')
 
-check('(a:b){c}', 'a', '(\e:b){c}')
-check('(a:b){c}', 'b', '(a:\e){c}')
-check('(a:b){c}', 'c', '\z{c}')
+check('(a:b){c}', 'a', r'(\e:b){c}')
+check('(a:b){c}', 'b', r'(a:\e){c}')
+check('(a:b){c}', 'c', r'\z{c}')
 
 check('(a*&a*){c}', 'a', '(a*&a*){c}')
-check('(a*&a*){c}', 'b', '\z{c}')
+check('(a*&a*){c}', 'b', r'\z{c}')
 
 check('(<x>(<y>a)*<z>){c}', 'a', '(<y>a)*{c}')
-check('(<x>(<y>a)*<z>){c}', 'b', '\z{c}')
+check('(<x>(<y>a)*<z>){c}', 'b', r'\z{c}')
 
-check('a{c}{c}', 'a', '\e{c}{c}')
-check('a{c}{c}', 'b', '\z{c}{c}')
+check('a{c}{c}', 'a', r'\e{c}{c}')
+check('a{c}{c}', 'b', r'\z{c}{c}')
 
 # We could easily generate an infinite derived-term automaton here.
 # However, currently we don't support a powerful enough normalization
@@ -169,7 +189,7 @@ check(e, 'aaaa', '((<2>a)*+(<4>(aa))*){c}')
 
 check('(<x>a)*', 'aa',   '<xx>(<x>a)*')
 check('(<x>a)*', 'aaaa', '<xxxx>(<x>a)*')
-check('(<x>a)*', 'aaab', '\z')
+check('(<x>a)*', 'aaab', r'\z')
 
 check('(<x>a)*(<y>b)*', 'aa',   '<xx>(<x>a)*(<y>b)*')
 check('(<x>a)*(<y>b)*', 'aabb', '<xxyy>(<y>b)*')
@@ -206,24 +226,24 @@ def check_br(re, letter, exp):
 ## ---------------------------- ##
 
 # Zero, one.
-check_br(   '\z', 'a', '\z')
-check_br(   '\e', 'a', '\z')
-check_br('<x>\e', 'a', '\z')
+check_br(   r'\z', 'a', r'\z')
+check_br(   r'\e', 'a', r'\z')
+check_br(r'<x>\e', 'a', r'\z')
 
 # Letters.
-check_br(   'a', 'a', '\e')
-check_br(   'a', 'b', '\z')
-check_br('<x>a', 'a', '<x>\e')
-check_br('<x>a', 'b', '\z')
+check_br(   'a', 'a', r'\e')
+check_br(   'a', 'b', r'\z')
+check_br('<x>a', 'a', r'<x>\e')
+check_br('<x>a', 'b', r'\z')
 
 # Sum.
-check_br('<x>a+<y>b', 'a', '<x>\e')
-check_br('<x>a+<y>b', 'b', '<y>\e')
-check_br('<x>a+<y>a', 'a', '<x+y>\e')
+check_br('<x>a+<y>b', 'a', r'<x>\e')
+check_br('<x>a+<y>b', 'b', r'<y>\e')
+check_br('<x>a+<y>a', 'a', r'<x+y>\e')
 
 # Prod.
 check_br('ab', 'a', 'b')
-check_br('ab', 'b', '\z')
+check_br('ab', 'b', r'\z')
 check_br('(<x>a)(<y>a)(<z>a)', 'a', '<xy>a<z>a')
 
 # Exterior products.
@@ -231,9 +251,9 @@ check_br('(<x>ab)<y>', 'a', '<xy>b')
 
 # Star.
 check_br('a*', 'a', 'a*')
-check_br('a*', 'b', '\z')
+check_br('a*', 'b', r'\z')
 check_br('(<x>a)*', 'a', '<x>(<x>a)*')
-check_br('(<x>a)*', 'b', '\z')
+check_br('(<x>a)*', 'b', r'\z')
 check_br('<x>a*',   'a', '<x>a*')
 check_br('<x>(<y>a)*', 'a', '<xy>(<y>a)*')
 
@@ -284,3 +304,35 @@ check_bdt(fig3, 'h3-dt-breaking')
 
 ctx = vcsn.context('lat<lal<char>, lal<char>>, q')
 check('ab|xy', 'a|x', 'b|y')
+
+ctx = vcsn.context('lat<lan<char>, lan<char>>, q')
+check('ab|xy', 'a|x', 'b|y')
+check('ab|xy', r'a|\e', r'\z')
+check('a*|x*', 'a|x', 'a*|x*')
+
+exp = ctx.expression
+e = exp('(a{+}|x + b{+}|y)*')
+f = exp(r'a*|\e') * e
+g = exp(r'b*|\e') * e
+z = exp(r'\z|\z')
+check_dt(e, 'ax-by')
+check(e, r'a|\e', str(z))
+check(e, 'a|x',   str(f))
+check(e, 'a|y',   str(z))
+check(e, r'b|\e', str(z))
+check(e, 'b|x',   str(z))
+check(e, 'b|y',   str(g))
+
+check(f, r'a|\e', str(f))
+check(f, 'a|x',   str(f))
+check(f, 'a|y',   str(z))
+check(f, r'b|\e', str(z))
+check(f, 'b|x',   str(z))
+check(f, 'b|y',   str(g))
+
+check(g, r'a|\e', str(z))
+check(g, 'a|x',   str(f))
+check(g, 'a|y',   str(z))
+check(g, r'b|\e', str(g))
+check(g, 'b|x',   str(z))
+check(g, 'b|y',   str(g))
