@@ -13,8 +13,11 @@ def check_enumerate(re, len, *exp):
   # have a means to build the right context, with LAW, not LAL etc.
   exp = " + ".join(exp)
   re = ctx.expression(re)
-  CHECK_EQ(exp, re.standard().shortest(len = len))
-  CHECK_EQ(exp, re.shortest(len = len))
+  CHECK_EQ(exp, re.standard().shortest(len=len))
+  CHECK_EQ(exp, re.shortest(len=len))
+
+def check_one(aut, num, exp):
+  CHECK_EQ(exp, aut.shortest(num=num))
 
 ## check_shortest RE NUM EXP
 ## --------------------------
@@ -24,8 +27,8 @@ def check_shortest(re, num, *exp):
   if num != 1:
       check_shortest(re, 1, split('[ +]+', exp)[0])
   re = ctx.expression(re)
-  CHECK_EQ(exp, re.standard().shortest(num = num))
-  CHECK_EQ(exp, re.shortest(num = num))
+  check_one(re.standard(), num, exp)
+  check_one(re, num, exp)
 
 
 ## check RE MAX WORD...
@@ -38,15 +41,15 @@ def check(re, size, *exp):
 
 ctx = vcsn.context('lal_char(ab), b')
 
-check('\z', 3, '\z')
-check('\e', 3, '\e')
+check(r'\z', 3, r'\z')
+check(r'\e', 3, r'\e')
 check('a+b', 2, 'a + b')
 check('ababab', 10, 'ababab')
 
-check_enumerate('(a+b)*', 2, '\e + a + b + aa + ab + ba + bb')
-check_shortest('(a+b)*', 2, '\e', 'a')
+check_enumerate('(a+b)*', 2, r'\e + a + b + aa + ab + ba + bb')
+check_shortest('(a+b)*', 2, r'\e', 'a')
 
-check_enumerate('ababab', 2, '\z')
+check_enumerate('ababab', 2, r'\z')
 check_shortest('ababab', 2, 'ababab')
 
 
@@ -59,15 +62,41 @@ check_enumerate('(0+1)*1(<2>0+<2>1)*', 3, \
 check_shortest('(0+1)*1(<2>0+<2>1)*', 3, '1 + 01 + <2>10')
 
 ctx = vcsn.context('lal_char(a), q')
-check('a+<-1>a', 2, '\z')
+check('a+<-1>a', 2, r'\z')
 
 # Wordset.
 ctx = vcsn.context('law_char(a), q')
-check_shortest('(a+aaa)*', 7, '\e + a + aa + <2>aaa + <3>aaaa + <4>aaaaa + <6>aaaaaa')
+check_shortest('(a+aaa)*', 7, r'\e + a + aa + <2>aaa + <3>aaaa + <4>aaaaa + <6>aaaaaa')
 
 # LAN x LAN
 ctx = vcsn.context('lat<lan_char(a), lan_char(x)>, q')
-check_shortest('(\e|x + a|\e)*', 9,
-               '\e|\e + \e|x + a|\e + <2>a|x + \e|xx + <3>a|xx + aa|\e + <3>aa|x + <6>aa|xx')
-check_enumerate('(\e|x + a|\e)*', 2,
-                '\e|\e + \e|x + a|\e + <2>a|x + \e|xx + <3>a|xx + aa|\e + <3>aa|x + <6>aa|xx')
+check_shortest(r'(\e|x + a|\e)*', 9,
+               r'\e|\e + \e|x + a|\e + <2>a|x + \e|xx + <3>a|xx + aa|\e + <3>aa|x + <6>aa|xx')
+check_enumerate(r'(\e|x + a|\e)*', 2,
+                r'\e|\e + \e|x + a|\e + <2>a|x + \e|xx + <3>a|xx + aa|\e + <3>aa|x + <6>aa|xx')
+
+aut = vcsn.automaton('''
+context = "letterset<char_letters(a)>, q"
+$ -> 0
+0 -> 1 <2>a
+0 -> 2 <-1>a
+0 -> 3 <-1>a
+1 -> $
+2 -> $
+3 -> $
+''')
+check_one(aut, 1, '\z')
+
+aut = vcsn.automaton('''
+context = "letterset<char_letters(ab)>, q"
+$ -> 0
+0 -> 1 <2>a
+0 -> 2 <-1>a
+0 -> 3 <-1>a
+0 -> 4 b
+1 -> $
+2 -> $
+3 -> $
+4 -> $
+''')
+check_one(aut, 1, 'b')
