@@ -6,12 +6,12 @@ from test import *
 def union(*auts):
     res = auts[0]
     for a in auts[1:]:
-        res = res.sum(a, "general")
+        res = res.add(a, "general")
     return res
 
 ab = vcsn.context('lal_char(ab), b').expression('(a+b)*').standard()
 bc = vcsn.context('lal_char(bc), b').expression('(b+c)*').standard()
-CHECK_EQ(vcsn.automaton(filename = medir + '/abc.gv'), union(ab, bc))
+CHECK_EQ(meaut('abc.gv'), union(ab, bc))
 
 ## ------------ ##
 ## lal_char_z.  ##
