@@ -42,25 +42,25 @@ xfail(r'(ab){T}')
 ## -------------- ##
 
 # "\z".
-check('\z',
-'''context = "nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>"
+check(r'\z',
+'''context = nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>
 $ -> 0
 1 -> $''')
 
 # "\e".
-check('\e',
-'''context = "nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>"
+check(r'\e',
+'''context = nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>
 $ -> 0
 0 -> $
 1 -> $''')
 
 ## ----- ##
-## sum.  ##
+## add.  ##
 ## ----- ##
 
 # "a+b"
 check('a+b',
-r'''context = "nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>"
+r'''context = nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>
 $ -> 0
 0 -> 1 \e
 0 -> 3 \e
@@ -71,8 +71,8 @@ $ -> 0
 5 -> $''')
 
 # "\e+a"
-check('\e+a',
-r'''context = "nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>"
+check(r'\e+a',
+r'''context = nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>
 $ -> 0
 0 -> $
 0 -> 1 \e
@@ -88,7 +88,7 @@ $ -> 0
 
 # "ab"
 check('ab',
-r'''context = "nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>"
+r'''context = nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>
 $ -> 0
 0 -> 1 \e
 1 -> 2 a
@@ -99,7 +99,7 @@ $ -> 0
 
 # "a?bb"
 check('a?bb',
-r'''context = "nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>"
+r'''context = nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>
 $ -> 0
 0 -> 1 \e
 1 -> 2 \e
@@ -123,7 +123,7 @@ $ -> 0
 
 # "a*"
 check('a*',
-r'''context = "nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>"
+r'''context = nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>
 $ -> 0
 0 -> $
 0 -> 1 \e
@@ -138,7 +138,7 @@ $ -> 0
 
 # <x>a*
 check('<x>a*',
-r'''context = "nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>"
+r'''context = nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>
 $ -> 0
 0 -> $ <x>
 0 -> 1 <x>\e
@@ -153,7 +153,7 @@ $ -> 0
 
 # (a?)<y>
 check('(a?)<y>',
-r'''context = "nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>"
+r'''context = nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>
 $ -> 0
 0 -> $ <y>
 0 -> 1 \e
@@ -169,7 +169,7 @@ $ -> 0
 
 # (<x>a?)<y>
 check('(<x>a?)<y>',
-r'''context = "nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>"
+r'''context = nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>
 $ -> 0
 0 -> $ <xy>
 0 -> 1 <x>\e
@@ -179,13 +179,13 @@ $ -> 0
 4 -> 5 \e
 5 -> $ <y>''')
 
-## ------------ ##
-## sum and prod ##
-## ------------ ##
+## ------------- ##
+## add and mul.  ##
+## ------------- ##
 
 # (a?b?+c?)
 check('(a?b?+c?)',
-r'''context = "nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>"
+r'''context = nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>
 $ -> 0
 0 -> $ <<2>\e>
 0 -> 1 \e
@@ -217,12 +217,12 @@ $ -> 0
 ## ------------- ##
 
 ## ----- ##
-## sum.  ##
+## add.  ##
 ## ----- ##
 
 # "a+b"
 check('a+b',
-r'''context = "nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>"
+r'''context = nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>
 $ -> 0
 0 -> 1 a
 0 -> 2 \e
@@ -232,8 +232,8 @@ $ -> 0
 'compact')
 
 # "\e+a"
-check('\e+a',
-r'''context = "nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>"
+check(r'\e+a',
+r'''context = nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>
 $ -> 0
 0 -> $
 0 -> 2 \e
@@ -248,7 +248,7 @@ $ -> 0
 
 # "ab"
 check('ab',
-r'''context = "nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>"
+r'''context = nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>
 $ -> 0
 0 -> 1 a
 1 -> 2 \e
@@ -258,7 +258,7 @@ $ -> 0
 
 # "a(a?b?)b"
 check('a(a?b?)b',
-r'''context = "nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>"
+r'''context = nullableset<letterset<char_letters(abc)>>, seriesset<letterset<char_letters(xyz)>, q>
 $ -> 0
 0 -> 1 a
 1 -> 2 \e
